# In R environment
#1. Download SRA data
setwd("GSE47817_SRP025153")
listSRAfile('SRP025153',sra_con)->SRP025153table
SRP025153table[,5]->files_url
SRP025153table[,4]->destination
write.table(files_url, file="files_url.txt", quote=F, col.names=F, row.names=F)
system("sudo sh 1.1.sh")

#2. Convert *.SRA to *.FASTQ
# 2.1 Download and install SRA Toolkit
system ('wget https://ftp-trace.ncbi.nlm.nih.gov/sra/sdk/2.8.2-1/sratoolkit.2.8.2-1-mac64.tar.gz') # Selected for MAC
library("R.utils")
system ("sudo ./fastq-dump --outdir /Users/apple/Desktop/NGS3/DATA/GSE47817_SRP025153 --split-files /Users/apple/Desktop/NGS3/DATA/GSE47817_SRP025153/*.sra")
# For each *.sra file a *_1.fastq and *_2.fastq files are formed for paired end data.





# In OS terminal
#2.2 Make data files appropriate for assembly
perl 1.2.pl

#3. Quality Control
./bbduk.sh in1=/home/vinay/c/PROCESSED_SRR892995_1.fastq in2=/home/vinay/Desktop/PROCESSED/PROCESSED_SRR892995_2.fastq out1=/home/vinay/Desktop/PROCESSED/CLEANED_SRR892995_1.fastq out2=/home/vinay/Desktop/PROCESSED/CLEANED_SRR892995_2.fastq t=4 ktrim=r ktrim=l ref=./resources/adapters.fa k=23 mink=11 qtrim=r trimq=10 tpe tbo

#4. Download and link the mouse genome files
#4.1 Downloaded the mouse genome (UCSC mm10) from the illumina website (https://support.illumina.com/sequencing/sequencing_software/igenome.html)

#4.2 Create a link to this file in your working directory. From your working directory, type:

ln -s /ASSEMBLY/GENOME/UCSC/Mus_musculus/UCSC/mm10/Annotation/Genes/genes.gtf
ln -s /ASSEMBLY/GENOME/UCSC/Mus_musculus/UCSC/mm10/Annotation/Genes/genome.*

#5. Read alignment and assembly
# Download and install packages Samtools; Tophat; Bowtie; Cufflinks, as specified in Trapnell et al., (2012)
# Reads alignment and assembly is performed, as specified in Trapnell et al., (2012)

#5.1 Align the RNA-seq reads to the genome
tophat -p 4 -G genes.gtf -o Y_R1_SRR892995 genome CLEANED_SRR892995_1.fastq CLEANED_SRR892995_2.fastq #Y_R*, for young samples
tophat -p 4 -G genes.gtf -o Y_R2_SRR892996 genome CLEANED_SRR892996_1.fastq CLEANED_SRR892996_2.fastq
tophat -p 4 -G genes.gtf -o Y_R3_SRR892997 genome CLEANED_SRR892997_1.fastq CLEANED_SRR892997_2.fastq
tophat -p 4 -G genes.gtf -o Y_R4_SRR892998 genome CLEANED_SRR892998_1.fastq CLEANED_SRR892998_2.fastq
tophat -p 4 -G genes.gtf -o O_R1_SRR892999 genome CLEANED_SRR892999_1.fastq CLEANED_SRR892999_2.fastq #O_R*, for old samples
tophat -p 4 -G genes.gtf -o O_R2_SRR893000 genome CLEANED_SRR893000_1.fastq CLEANED_SRR893000_2.fastq
tophat -p 4 -G genes.gtf -o O_R3_SRR893001 genome CLEANED_SRR893001_1.fastq CLEANED_SRR893001_2.fastq
tophat -p 4 -G genes.gtf -o O_R4_SRR893002 genome CLEANED_SRR893002_1.fastq CLEANED_SRR893002_2.fastq

#5.2 Assemble expressed genes and transcripts
cufflinks -p 4 -G -o Y_R1_SRR892995_out Y_R1_SRR892995/accepted_hits.bam
cufflinks -p 4 -G -o Y_R2_SRR892996_out Y_R2_SRR892996/accepted_hits.bam 
cufflinks -p 4 -G -o Y_R3_SRR892997_out Y_R3_SRR892997/accepted_hits.bam 
cufflinks -p 4 -G -o Y_R4_SRR892998_out Y_R4_SRR892998/accepted_hits.bam
cufflinks -p 4 -G -o O_R1_SRR892999_out O_R1_SRR892999/accepted_hits.bam 
cufflinks -p 4 -G -o O_R2_SRR893000_out O_R2_SRR893000/accepted_hits.bam 
cufflinks -p 4 -G -o O_R3_SRR893001_out O_R3_SRR893001/accepted_hits.bam
cufflinks -p 4 -G -o O_R4_SRR893002_out O_R4_SRR893002/accepted_hits.bam

#5.2.1 Create a file called assemblies.txt that lists the assembly file for each sample. The file should contain the following lines:
./Y_R1_SRR892995_out/transcripts.gtf
./Y_R2_SRR892996_out/transcripts.gtf
./Y_R3_SRR892997_out/transcripts.gtf
./Y_R4_SRR892998_out/transcripts.gtf
./O_R1_SRR892999_out/transcripts.gtf
./O_R2_SRR893000_out/transcripts.gtf
./O_R3_SRR893001_out/transcripts.gtf
./O_R4_SRR893002_out/transcripts.gtf

#5.2.2 Run Cuffmerge on all your assemblies to create a single merged transcriptome annotation:
cuffmerge -g genes.gtf -s genome.fa -p 4 assemblies.txt


#5.3 Identify differentially expressed genes and transcripts
cuffdiff -o diff_out -b genome.fa -p 4 -L Y,O -u merged_asm/merged.gtf ./Y_R1_SRR892995/accepted_hits.bam,./Y_R2_SRR892996/accepted_hits.bam,./Y_R3_SRR892997/accepted_hits.bam,./Y_R4_SRR892998/accepted_hits.bam ./O_R1_SRR892999/accepted_hits.bam,./O_R2_SRR893000/accepted_hits.bam,./O_R3_SRR893001/accepted_hits.bam,./O_R4_SRR893002/accepted_hits.bam

#In the current working directory, "diff_out" folder will be created that includes all the differential expression results

#Note: The same data assembly and annotation approach was used for processing GSE41658 dataset









