#1. Deciphering regulatory relations from interaction databases

#1.1 TF-gene/miRNA regulatory relations (Downloaded from ChIPBase v2.0)
#1.1.1 TF-gene
#1.1.2 TF-miRNA

#1.2 miRNA-gene/TF regulatory relations (Downloaded from ensemble of DIANA-TarBase and miRTarBase)
#1.2.1 miRNA-gene
#1.2.2 miRNA-TF

#1.3 Merge all 4 regulatry interactions together (e.g., network_pairs.ncol)


#2. Identify the 3-node cliques in native network
library(igraph)
read.graph("network_pairs.ncol", format="ncol")->g
cliques(g, min = 3, max = 3)->num_cliques
n <- matrix(ncol=3, nrow=length(num_cliques))
{
n[i,1]<-names(unlist(as.list(num_cliques[i])))[1]
n[i,2]<-names(unlist(as.list(num_cliques[i])))[2]
n[i,3]<-names(unlist(as.list(num_cliques[i])))[3]
}
print(n);
as.data.frame(n)->network_motifs


#3. Assessing the statistical significance of 3 node cliques against TFs

system("perl 5.1.pl") #TFs permutation for one network
system("sh 4.2.sh") #TFs permutation for random networks

#3.1. Network rewiring and clique prediction in random networks
library(igraph)
myFiles <- list.files(pattern="Iteration*")
dat<-lapply(myFiles,read.table)
randomTFS = list()
for (i in 1:1000)
{
g_TFR <- graph.data.frame(dat[i],directed=F)
set.seed(i)
G_TFR <- rewire(g_TFR, with = keeping_degseq(niter = 100))
cliques(G_TFR, min = 3, max = 3)->C_TFR
print (length(C_TFR))
randomTFS[[i]]<-length(C_TFR)
}

#3.2 Assessing statistical significance of network motifs
unlist(randomTFS)->random_loop_TFs
as.numeric(random_loop_TFs)->random_loop_TFs
randTF_sd <- sd(random_loop_TFs)*sqrt((length(random_loop_TFs)-1)/(length(random_loop_TFs)))
z_randTF <- (random_loop_TFs-length(FFLS)) / randTF_sd
pvalue_two_tailed_randTF = 2*pnorm(-abs(z_randTF))
tTF <- (mean(random_loop_TFs)-2305)/(sd(random_loop_TFs)/sqrt(length(random_loop_TFs)))
2*pt(-abs(tTF),df=length(random_loop_TFs)-1)
write.table(as.data.frame(pvalue_two_tailed_randTF), file="Statistical_significance_pvalues_Random1000.txt", quote=F, sep="\t", col.names=FALSE)

#6. Assessing the statistical significance of 3 node cliques against miRNA
# Same as point number 3. except the list of TFs will be replaced by list of all miRNAs








