#1. Load essential libraries
library("GO.db")
library("annotate")
library("org.Hs.eg.db")	
library("GOstats")
library("RSQLite") 
library("clusterProfiler")
library("org.Hs.eg.db")	
keytypes(org.Hs.eg.db)
library(clusterProfiler)
	
#2. Converting Gene Symbols to ENTREZ Ids
black_genes_CF <- bitr(black_genes, fromType="SYMBOL", toType=(c("ENTREZID","ALIAS","GENENAME")), annoDb="org.Hs.eg.db")
unique(black_genes_CF[,2])->black_genes_ENTREZ

green_genes_CF <- bitr(green_genes, fromType="SYMBOL", toType=(c("ENTREZID","ALIAS","GENENAME")), annoDb="org.Hs.eg.db")
unique(green_genes_CF[,2])->green_genes_ENTREZ

red_genes_CF <- bitr(red_genes, fromType="SYMBOL", toType=(c("ENTREZID","ALIAS","GENENAME")), annoDb="org.Hs.eg.db")
unique(red_genes_CF[,2])->red_genes_ENTREZ


#3. Test for enrichment
goHypGparams_black <- new("GOHyperGParams", geneIds = black_genes_ENTREZ, annotation = "org.Hs.eg.db", ontology = "BP", pvalueCutoff = 0.05, conditional = FALSE, testDirection = "over")
goHypGcond_black <- hyperGTest(goHypGparams_black)
summary(goHypGcond_black)

goHypGparams_green <- new("GOHyperGParams", geneIds = green_genes_ENTREZ, annotation = "org.Hs.eg.db", ontology = "BP", pvalueCutoff = 0.05, conditional = FALSE, testDirection = "over")
goHypGcond_green <- hyperGTest(goHypGparams_green)
summary(goHypGcond_green)

goHypGparams_red <- new("GOHyperGParams", geneIds = red_genes_ENTREZ, annotation = "org.Hs.eg.db", ontology = "BP", pvalueCutoff = 0.05, conditional = FALSE, testDirection = "over")
goHypGcond_red <- hyperGTest(goHypGparams_red)
summary(goHypGcond_red)


goresult_black <- summary(goHypGcond_black)
goresult_black
head(goresult_black)
names(goresult_black)
goresult_black[order(goresult_black$Count),]
goresult_black_sorted<-goresult_black[rev(order(goresult_black$Count)),]
write.csv(goresult_black_sorted, file="goresult_black_module.xls")

goresult_green <- summary(goHypGcond_green)
goresult_green
head(goresult_green)
names(goresult_green)
goresult_green[order(goresult_green$Count),]
goresult_green_sorted<-goresult_green[rev(order(goresult_green$Count)),]
write.csv(goresult_green_sorted, file="goresult_green_module.xls")

goresult_red <- summary(goHypGcond_red)
goresult_red
head(goresult_red)
names(goresult_red)
goresult_red[order(goresult_red$Count),]
goresult_red_sorted<-goresult_red[rev(order(goresult_red$Count)),]
write.csv(goresult_red_sorted, file="goresult_red_module.xls")


#3.1 Function to include gene names in respective pathways
####################################################################

GOreport <- function(goHypGresult, chip, highlightedGenes=NULL) {

  cats <- sigCategories(goHypGresult)
  reportGenes <- vector()
  for (i in 1:length(cats)) {
    reportGenes <- append(reportGenes, geneIdsByCategory(goHypGresult,
cats[i]))
  }
  reportGeneSyms <- sapply(reportGenes, function(egIDs) {
    syms <- as.vector(unlist(mget(egIDs, getAnnMap(map="SYMBOL",
chip=chip,
                                                   type="db"))))
    syms <- sort(syms)
    syms <- sapply(1:length(egIDs),
                   function(i, egIDs) {
                     s <- syms[i]
                     if (!is.null(highlightedGenes) &&
                         !is.na(match(egIDs[i],
                                      highlightedGenes))) {
                       s <- sprintf("{\\bf %s}", s)
                     }
                     s
                   }, egIDs)
    paste(syms, collapse=", ")
  })
  reportGenes <- sapply(reportGenes, function(x) {
                                       paste(x, collapse=",")
                                     })
  report <- data.frame(summary(goHypGresult), GeneSyms=reportGeneSyms,
Genes=reportGenes)
  rownames(report) <- NULL
  report[sort(report$"OddsRatio", decreasing=TRUE,
index.return=TRUE)$ix, ]
}

# 3.2 Call the function to include the gene names as well
report_black <- GOreport(goHypGcond_black, "org.Hs.eg.db", NULL)
report_black_sorted<-report_black[rev(order(report_black$Count)),] #Sort Count in decreasing order.

report_green <- GOreport(goHypGcond_green, "org.Hs.eg.db", NULL)
report_green_sorted<-report_green[rev(order(report_green$Count)),] 

report_red <- GOreport(goHypGcond_red, "org.Hs.eg.db", NULL)
report_red_sorted<-report_red[rev(order(report_red$Count)),]

# 4. Summarize the significant GO terms in REVIGO












